==> nosql-database_24.4.zip: nosql-database_24.4_20241213/content/streams/toc.js <==
define(
{
    "reducedVersion":true,
    "toc":[
        {
            "heading":"Table of Contents",
            "topics":[
                {
                    "title":"Title and Copyright Information",
                    "href":"index.html"
                },
                {
                    "title":"Preface",
                    "href":"preface.html#GUID-E57B2756-704A-4D85-AB49-018F999CA867"
                },
                {
                    "title":"<span class=\"secnum\">1 </span> Introduction to the Oracle NoSQL Database Streams API",
                    "href":"introduction.html",
                    "topics":[
                        {
                            "title":"Architecture",
                            "href":"architecture.html"
                        },
                        {
                            "title":"API Components",
                            "href":"api-components.html"
                        },
                        {
                            "title":"Checkpoints",
                            "href":"checkpoints.html"
                        },
                        {
                            "title":"Dynamic Streaming",
                            "href":"dynamic-streaming.html"
                        },
                        {
                            "title":"System Requirements",
                            "href":"system-requirements.html"
                        },
                        {
                            "title":"Limitations",
                            "href":"limitations.html"
                        },
                        {
                            "title":"Compiling and Running a Streams Application",
                            "href":"compiling-and-running-streams-application.html"
                        }
                    ]
                },
                {
                    "title":"<span class=\"secnum\">2 </span> Using the StreamOperation Class",
                    "href":"using-streamoperation-class.html"
                },
                {
                    "title":"<span class=\"secnum\">3 </span> Working with Subscriptions",
                    "href":"working-subscriptions.html",
                    "topics":[
                        {
                            "title":"Using NoSQLSubscriptionConfig",
                            "href":"using-nosqlsubscriptionconfig.html"
                        },
                        {
                            "title":"NoSQLStreamMode",
                            "href":"nosqlstreammode.html"
                        },
                        {
                            "title":"Using NoSQLSubscription",
                            "href":"using-nosqlsubscription.html"
                        }
                    ]
                },
                {
                    "title":"<span class=\"secnum\">4 </span> Implementing Subscribers",
                    "href":"implementing-subscribers.html",
                    "topics":[
                        {
                            "title":"Using the NoSQLSubscriber Interface",
                            "href":"using-nosqlsubscriber-interface.html"
                        },
                        {
                            "title":"NoSQLSubscriber Example",
                            "href":"nosqlsubscriber-example.html"
                        }
                    ]
                },
                {
                    "title":"<span class=\"secnum\">5 </span> Using a Streams Publisher",
                    "href":"using-streams-publisher.html",
                    "topics":[
                        {
                            "title":"Using NoSQLPublisherConfig",
                            "href":"using-nosqlpublisherconfig.html#GUID-793D71B5-0A05-40B8-AA62-F7AAB995D9C2"
                        },
                        {
                            "title":"Streams Example",
                            "href":"streams-example.html#GUID-7EFC1B81-93C3-4267-99E4-20B47E3E0C72"
                        }
                    ]
                },
                {
                    "title":"<span class=\"secnum\">6 </span> Using Checkpoints",
                    "href":"using-checkpoints.html",
                    "topics":[
                        {
                            "title":"Implementing Checkpoints in GSGStreamExample",
                            "href":"implementing-checkpoints-gsgstreamexample.html"
                        },
                        {
                            "title":"Implementing Checkpoints in GSGSubscriberExample",
                            "href":"implementing-checkpoints-gsgsubscriberexample.html"
                        },
                        {
                            "title":"Example Checkpoint Behavior",
                            "href":"example-checkpoint-behavior.html"
                        }
                    ]
                },
                {
                    "title":"<span class=\"secnum\">7 </span> Scaling a Streams Application",
                    "href":"scaling-streams-application.html",
                    "topics":[
                        {
                            "title":"Scaling Subscribers",
                            "href":"scaling-subscribers.html"
                        }
                    ]
                },
                {
                    "title":"<span class=\"secnum\">A </span> GSGStreamsWriteTable",
                    "href":"gsgstreamswritetable.html"
                }
            ]
        }
    ]
});

==> nosql-database_25.3.zip: nosql-database_25.3_20251015/content/streams/toc.js <==
define(
{
    "reducedVersion":true,
    "toc":[
        {
            "heading":"Table of Contents",
            "topics":[
                {
                    "title":"Title and Copyright Information",
                    "href":"index.html"
                },
                {
                    "title":"Preface",
                    "href":"preface.html#GUID-E57B2756-704A-4D85-AB49-018F999CA867"
                },
                {
                    "title":"<span class=\"secnum\">1 </span> Introduction to the Oracle NoSQL Database Streams API",
                    "href":"introduction.html",
                    "topics":[
                        {
                            "title":"Architecture",
                            "href":"architecture.html"
                        },
                        {
                            "title":"API Components",
                            "href":"api-components.html"
                        },
                        {
                            "title":"Checkpoints",
                            "href":"checkpoints.html"
                        },
                        {
                            "title":"Dynamic Streaming",
                            "href":"dynamic-streaming.html"
                        },
                        {
                            "title":"Row metadata Streaming",
                            "href":"row-metadata-streaming.html"
                        },
                        {
                            "title":"Before-images Streaming",
                            "href":"images-streaming.html"
                        },
                        {
                            "title":"Transaction Events Streaming",
                            "href":"transaction-events-streaming.html"
                        },
                        {
                            "title":"System Requirements",
                            "href":"system-requirements.html"
                        },
                        {
                            "title":"Limitations",
                            "href":"limitations.html"
                        },
                        {
                            "title":"Compiling and Running a Streams Application",
                            "href":"compiling-and-running-streams-application.html"
                        }
                    ]
                },
                {
                    "title":"<span class=\"secnum\">2 </span> Using the StreamOperation Class",
                    "href":"using-streamoperation-class.html"
                },
                {
                    "title":"<span class=\"secnum\">3 </span> Working with Subscriptions",
                    "href":"working-subscriptions.html",
                    "topics":[
                        {
                            "title":"Using NoSQLSubscriptionConfig",
                            "href":"using-nosqlsubscriptionconfig.html",
                            "topics":[
                                {
                                    "title":"Configuring Before-images Streaming",
                                    "href":"configuring-images-streaming.html"
                                },
                                {
                                    "title":"Configuring Transaction Event Streaming",
                                    "href":"configuring-transaction-event-streaming.html"
                                }
                            ]
                        },
                        {
                            "title":"NoSQLStreamMode",
                            "href":"nosqlstreammode.html"
                        },
                        {
                            "title":"Using NoSQLSubscription",
                            "href":"using-nosqlsubscription.html"
                        }
                    ]
                },
                {
                    "title":"<span class=\"secnum\">4 </span> Implementing Subscribers",
                    "href":"implementing-subscribers.html",
                    "topics":[
                        {
                            "title":"Using the NoSQLSubscriber Interface",
                            "href":"using-nosqlsubscriber-interface.html"
                        },
                        {
                            "title":"NoSQLSubscriber Example",
                            "href":"nosqlsubscriber-example.html",
                            "topics":[
                                {
                                    "title":"NoSQLSubscriber Example with Before-images Streaming",
                                    "href":"nosqlsubscriber-example-images-streaming.html"
                                },
                                {
                                    "title":"NoSQLSubscriber Example with Transaction Event Streaming",
                                    "href":"nosqlsubscriber-example-transaction-event-streaming.html"
                                }
                            ]
                        }
                    ]
                },
                {
                    "title":"<span class=\"secnum\">5 </span> Using a Streams Publisher",
                    "href":"using-streams-publisher.html",
                    "topics":[
                        {
                            "title":"Using NoSQLPublisherConfig",
                            "href":"using-nosqlpublisherconfig.html#GUID-793D71B5-0A05-40B8-AA62-F7AAB995D9C2"
                        },
                        {
                            "title":"Streams Example",
                            "href":"streams-example.html#GUID-7EFC1B81-93C3-4267-99E4-20B47E3E0C72"
                        }
                    ]
                },
                {
                    "title":"<span class=\"secnum\">6 </span> Using Checkpoints",
                    "href":"using-checkpoints.html",
                    "topics":[
                        {
                            "title":"Implementing Checkpoints in GSGStreamExample",
                            "href":"implementing-checkpoints-gsgstreamexample.html"
                        },
                        {
                            "title":"Implementing Checkpoints in GSGSubscriberExample",
                            "href":"implementing-checkpoints-gsgsubscriberexample.html"
                        },
                        {
                            "title":"Example Checkpoint Behavior",
                            "href":"example-checkpoint-behavior.html"
                        }
                    ]
                },
                {
                    "title":"<span class=\"secnum\">7 </span> Scaling a Streams Application",
                    "href":"scaling-streams-application.html",
                    "topics":[
                        {
                            "title":"Scaling Subscribers",
                            "href":"scaling-subscribers.html"
                        }
                    ]
                },
                {
                    "title":"<span class=\"secnum\">A </span> GSGStreamsWriteTable",
                    "href":"gsgstreamswritetable.html"
                }
            ]
        }
    ]
});
